diff graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/bridge/VMToCompilerImpl.java @ 8410:e996a732c740

renamings as part of a move away from the overloading of the "snippet" term for various code replacement/substitution mechanisms towards it being solely for the concept of IR lowering
author Doug Simon <doug.simon@oracle.com>
date Wed, 20 Mar 2013 20:23:23 +0100
parents a202f72872a4
children 2361bf148c06
line wrap: on
line diff
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/bridge/VMToCompilerImpl.java	Wed Mar 20 18:16:45 2013 +0100
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/bridge/VMToCompilerImpl.java	Wed Mar 20 20:23:23 2013 +0100
@@ -144,16 +144,16 @@
         // Install intrinsics.
         final HotSpotRuntime runtime = graalRuntime.getCapability(HotSpotRuntime.class);
         if (GraalOptions.Intrinsify) {
-            Debug.scope("InstallSnippets", new Object[]{new DebugDumpScope("InstallSnippets")}, new Runnable() {
+            Debug.scope("InstallReplacements", new Object[]{new DebugDumpScope("InstallReplacements")}, new Runnable() {
 
                 @Override
                 public void run() {
                     // Snippets cannot have speculative optimizations since they have to be valid
                     // for the entire run of the VM.
                     Assumptions assumptions = new Assumptions(false);
-                    SnippetInstaller installer = new HotSpotSnippetInstaller(runtime, assumptions, runtime.getGraalRuntime().getTarget());
+                    ReplacementsInstaller installer = new HotSpotReplacementsInstaller(runtime, assumptions, runtime.getGraalRuntime().getTarget());
                     GraalIntrinsics.installIntrinsics(installer);
-                    runtime.installSnippets(graalRuntime.getBackend(), installer, assumptions);
+                    runtime.installReplacements(graalRuntime.getBackend(), installer, assumptions);
                 }
             });
@@ -144,16 +144,16 @@
                 @Override
                 public void run() {
-                    // Snippets cannot have speculative optimizations since they have to be valid
-                    // for the entire run of the VM.
+                    // Replacements cannot have speculative optimizations since they have
+                    // to be valid for the entire run of the VM.
                     Assumptions assumptions = new Assumptions(false);